==> driftctl-0.14.0.tar.gz: driftctl-0.14.0/CONTRIBUTORS.md <==
# Contributors

Thank you to all the people who have already contributed to driftctl.

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/sjourdan"><img src="https://avatars.githubusercontent.com/u/419121?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Stephane Jourdan</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sjourdan" title="Documentation">📖</a> <a href="#ideas-sjourdan" title="Ideas, Planning, & Feedback">🤔</a> <a href="#talk-sjourdan" title="Talks">📢</a> <a href="#question-sjourdan" title="Answering Questions">💬</a></td>
    <td align="center"><a href="https://www.elie.ski"><img src="https://avatars.githubusercontent.com/u/6154987?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Elie</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=eliecharra" title="Documentation">📖</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=eliecharra" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Aeliecharra" title="Bug reports">🐛</a> <a href="https://github.com/cloudskiff/driftctl/pulls?q=is%3Apr+reviewed-by%3Aeliecharra" title="Reviewed Pull Requests">👀</a> <a href="#maintenance-eliecharra" title="Maintenance">🚧</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=eliecharra" title="Tests">⚠️</a> <a href="#infra-eliecharra" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="http://moadib.net"><img src="https://avatars.githubusercontent.com/u/4931174?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Martin</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=moadibfr" title="Documentation">📖</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=moadibfr" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Amoadibfr" title="Bug reports">🐛</a> <a href="https://github.com/cloudskiff/driftctl/pulls?q=is%3Apr+reviewed-by%3Amoadibfr" title="Reviewed Pull Requests">👀</a> <a href="#maintenance-moadibfr" title="Maintenance">🚧</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=moadibfr" title="Tests">⚠️</a></td>
    <td align="center"><a href="http://wbeuil.com"><img src="https://avatars.githubusercontent.com/u/8110579?v=4?s=80" width="80px;" alt=""/><br /><sub><b>William BEUIL</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=wbeuil" title="Documentation">📖</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=wbeuil" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Awbeuil" title="Bug reports">🐛</a> <a href="https://github.com/cloudskiff/driftctl/pulls?q=is%3Apr+reviewed-by%3Awbeuil" title="Reviewed Pull Requests">👀</a> <a href="#maintenance-wbeuil" title="Maintenance">🚧</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=wbeuil" title="Tests">⚠️</a> <a href="#tool-wbeuil" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/emahe22"><img src="https://avatars.githubusercontent.com/u/22610513?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Eric MAHE</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=emahe22" title="Documentation">📖</a> <a href="#ideas-emahe22" title="Ideas, Planning, & Feedback">🤔</a> <a href="#business-emahe22" title="Business development">💼</a> <a href="#fundingFinding-emahe22" title="Funding Finding">🔍</a></td>
    <td align="center"><a href="http://driftctl.com/"><img src="https://avatars.githubusercontent.com/u/39477124?v=4?s=80" width="80px;" alt=""/><br /><sub><b>GeraldC</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=GeraldC13" title="Documentation">📖</a> <a href="#ideas-GeraldC13" title="Ideas, Planning, & Feedback">🤔</a> <a href="#business-GeraldC13" title="Business development">💼</a> <a href="#content-GeraldC13" title="Content">🖋</a></td>
    <td align="center"><a href="http://b.juglas.name"><img src="https://avatars.githubusercontent.com/u/5703?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Bertrand Juglas</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=bertux" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/sshota0809"><img src="https://avatars.githubusercontent.com/u/8736380?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Suzuki Shota</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sshota0809" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Asshota0809" title="Bug reports">🐛</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/sfenman"><img src="https://avatars.githubusercontent.com/u/43748066?v=4?s=80" width="80px;" alt=""/><br /><sub><b>sfenman</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sfenman" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/herbygillot"><img src="https://avatars.githubusercontent.com/u/618376?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Herby Gillot</b></sub></a><br /><a href="#tool-herbygillot" title="Tools">🔧</a></td>
    <td align="center"><a href="http://louistoussaint.fr"><img src="https://avatars.githubusercontent.com/u/66522867?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Toussaint Louis</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=lotoussa" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=lotoussa" title="Documentation">📖</a></td>
    <td align="center"><a href="https://dev.to/psedge"><img src="https://avatars.githubusercontent.com/u/5781397?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Peter Sedgewick</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=psedge" title="Documentation">📖</a></td>
    <td align="center"><a href="https://crvx.fr/"><img src="https://avatars.githubusercontent.com/u/16480203?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Raphaël</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sundowndev" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/vainkop"><img src="https://avatars.githubusercontent.com/u/28118190?v=4?s=80" width="80px;" alt=""/><br /><sub><b>vainkop</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Avainkop" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://remidoreau.com"><img src="https://avatars.githubusercontent.com/u/32459935?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Rémi Doreau</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=ayshiff" title="Code">💻</a></td>
    <td align="center"><a href="https://vorobiev.cloud"><img src="https://avatars.githubusercontent.com/u/197565?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Anton Vorobiev</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Aa-vorobiev" title="Bug reports">🐛</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

==> driftctl-0.16.0.tar.gz: driftctl-0.16.0/CONTRIBUTORS.md <==
# Contributors

Thank you to all the people who have already contributed to driftctl.

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/sjourdan"><img src="https://avatars.githubusercontent.com/u/419121?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Stephane Jourdan</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sjourdan" title="Documentation">📖</a> <a href="#ideas-sjourdan" title="Ideas, Planning, & Feedback">🤔</a> <a href="#talk-sjourdan" title="Talks">📢</a> <a href="#question-sjourdan" title="Answering Questions">💬</a></td>
    <td align="center"><a href="https://www.elie.ski"><img src="https://avatars.githubusercontent.com/u/6154987?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Elie</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=eliecharra" title="Documentation">📖</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=eliecharra" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Aeliecharra" title="Bug reports">🐛</a> <a href="https://github.com/cloudskiff/driftctl/pulls?q=is%3Apr+reviewed-by%3Aeliecharra" title="Reviewed Pull Requests">👀</a> <a href="#maintenance-eliecharra" title="Maintenance">🚧</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=eliecharra" title="Tests">⚠️</a> <a href="#infra-eliecharra" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="http://moadib.net"><img src="https://avatars.githubusercontent.com/u/4931174?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Martin</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=moadibfr" title="Documentation">📖</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=moadibfr" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Amoadibfr" title="Bug reports">🐛</a> <a href="https://github.com/cloudskiff/driftctl/pulls?q=is%3Apr+reviewed-by%3Amoadibfr" title="Reviewed Pull Requests">👀</a> <a href="#maintenance-moadibfr" title="Maintenance">🚧</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=moadibfr" title="Tests">⚠️</a></td>
    <td align="center"><a href="http://wbeuil.com"><img src="https://avatars.githubusercontent.com/u/8110579?v=4?s=80" width="80px;" alt=""/><br /><sub><b>William BEUIL</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=wbeuil" title="Documentation">📖</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=wbeuil" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Awbeuil" title="Bug reports">🐛</a> <a href="https://github.com/cloudskiff/driftctl/pulls?q=is%3Apr+reviewed-by%3Awbeuil" title="Reviewed Pull Requests">👀</a> <a href="#maintenance-wbeuil" title="Maintenance">🚧</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=wbeuil" title="Tests">⚠️</a> <a href="#tool-wbeuil" title="Tools">🔧</a></td>
    <td align="center"><a href="https://github.com/emahe22"><img src="https://avatars.githubusercontent.com/u/22610513?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Eric MAHE</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=emahe22" title="Documentation">📖</a> <a href="#ideas-emahe22" title="Ideas, Planning, & Feedback">🤔</a> <a href="#business-emahe22" title="Business development">💼</a> <a href="#fundingFinding-emahe22" title="Funding Finding">🔍</a></td>
    <td align="center"><a href="http://driftctl.com/"><img src="https://avatars.githubusercontent.com/u/39477124?v=4?s=80" width="80px;" alt=""/><br /><sub><b>GeraldC</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=GeraldC13" title="Documentation">📖</a> <a href="#ideas-GeraldC13" title="Ideas, Planning, & Feedback">🤔</a> <a href="#business-GeraldC13" title="Business development">💼</a> <a href="#content-GeraldC13" title="Content">🖋</a></td>
    <td align="center"><a href="http://b.juglas.name"><img src="https://avatars.githubusercontent.com/u/5703?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Bertrand Juglas</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=bertux" title="Documentation">📖</a></td>
    <td align="center"><a href="https://github.com/sshota0809"><img src="https://avatars.githubusercontent.com/u/8736380?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Suzuki Shota</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sshota0809" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Asshota0809" title="Bug reports">🐛</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/sfenman"><img src="https://avatars.githubusercontent.com/u/43748066?v=4?s=80" width="80px;" alt=""/><br /><sub><b>sfenman</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sfenman" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/herbygillot"><img src="https://avatars.githubusercontent.com/u/618376?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Herby Gillot</b></sub></a><br /><a href="#tool-herbygillot" title="Tools">🔧</a></td>
    <td align="center"><a href="http://louistoussaint.fr"><img src="https://avatars.githubusercontent.com/u/66522867?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Toussaint Louis</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=lotoussa" title="Code">💻</a> <a href="https://github.com/cloudskiff/driftctl/commits?author=lotoussa" title="Documentation">📖</a></td>
    <td align="center"><a href="https://dev.to/psedge"><img src="https://avatars.githubusercontent.com/u/5781397?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Peter Sedgewick</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=psedge" title="Documentation">📖</a></td>
    <td align="center"><a href="https://crvx.fr/"><img src="https://avatars.githubusercontent.com/u/16480203?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Raphaël</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=sundowndev" title="Code">💻</a></td>
    <td align="center"><a href="https://github.com/vainkop"><img src="https://avatars.githubusercontent.com/u/28118190?v=4?s=80" width="80px;" alt=""/><br /><sub><b>vainkop</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Avainkop" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://remidoreau.com"><img src="https://avatars.githubusercontent.com/u/32459935?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Rémi Doreau</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=ayshiff" title="Code">💻</a></td>
    <td align="center"><a href="https://vorobiev.cloud"><img src="https://avatars.githubusercontent.com/u/197565?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Anton Vorobiev</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/issues?q=author%3Aa-vorobiev" title="Bug reports">🐛</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://orenleung.com"><img src="https://avatars.githubusercontent.com/u/47992694?v=4?s=80" width="80px;" alt=""/><br /><sub><b>Oren Leung</b></sub></a><br /><a href="https://github.com/cloudskiff/driftctl/commits?author=OrenLeung" title="Code">💻</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
